@@ -4,7 +4,7 @@
  *	  fetch tuples from a RUM scan.
  *
  *
- * Portions Copyright (c) 2015-2022, Postgres Professional
+ * Portions Copyright (c) 2015-2025, Postgres Professional
  * Portions Copyright (c) 1996-2022, PostgreSQL Global Development Group
  * Portions Copyright (c) 1994, Regents of the University of California
  *
@@ -255,7 +255,7 @@ scanPostingTree(Relation index, RumScanEntry scanEntry,
 			Pointer		ptr;
 
 			MemSet(&item, 0, sizeof(item));
-			ItemPointerSetMin(&item.item.iptr);
+			RumItemPointerSetMin(&item.item.iptr);
 
 			ptr = RumDataPageGetData(page);
 			for (i = FirstOffsetNumber; i <= maxoff; i++)
@@ -468,7 +468,7 @@ collectMatchBitmap(RumBtreeData * btree, RumBtreeStack * stack,
 			RumScanItem item;
 
 			MemSet(&item, 0, sizeof(item));
-			ItemPointerSetMin(&item.item.iptr);
+			RumItemPointerSetMin(&item.item.iptr);
 			for (i = 0; i < RumGetNPosting(itup); i++)
 			{
 				ptr = rumDataPageLeafRead(ptr, scanEntry->attnum, &item.item,
@@ -608,7 +608,7 @@ restartScanEntry:
 		if (entry->matchSortstate)
 		{
 			rum_tuplesort_performsort(entry->matchSortstate);
-			ItemPointerSetMin(&entry->collectRumItem.item.iptr);
+			RumItemPointerSetMin(&entry->collectRumItem.item.iptr);
 			entry->isFinished = false;
 		}
 	}
@@ -637,7 +637,7 @@ restartScanEntry:
 			Pointer		ptr;
 			RumItem		item;
 
-			ItemPointerSetMin(&item.iptr);
+			RumItemPointerSetMin(&item.iptr);
 
 			/*
 			 * We should unlock entry page before touching posting tree to
@@ -889,7 +889,14 @@ entryGetNextItem(RumState * rumstate, RumScanEntry entry, Snapshot snapshot)
 
 		LockBuffer(entry->buffer, RUM_SHARE);
 		page = BufferGetPage(entry->buffer);
-
+		if (!RumPageIsLeaf(page))
+		{
+			/*
+			 * Root page becomes non-leaf while we unlock it. just return.
+			 */
+			LockBuffer(entry->buffer, RUM_UNLOCK);
+			return;
+		}
 		PredicateLockPage(rumstate->index, BufferGetBlockNumber(entry->buffer), snapshot);
 
 		if (scanPage(rumstate, entry, &entry->curItem, false))
@@ -934,7 +941,7 @@ entryGetNextItem(RumState * rumstate, RumScanEntry entry, Snapshot snapshot)
 			entry->offset = -1;
 			maxoff = RumPageGetOpaque(page)->maxoff;
 			entry->nlist = maxoff;
-			ItemPointerSetMin(&item.iptr);
+			RumItemPointerSetMin(&item.iptr);
 			ptr = RumDataPageGetData(page);
 
 			for (i = FirstOffsetNumber; i <= maxoff; i = OffsetNumberNext(i))
@@ -1055,7 +1062,7 @@ entryGetNextItemList(RumState * rumstate, RumScanEntry entry, Snapshot snapshot)
 		Pointer		ptr;
 		RumItem		item;
 
-		ItemPointerSetMin(&item.iptr);
+		RumItemPointerSetMin(&item.iptr);
 
 		/*
 		 * We should unlock entry page before touching posting tree to
@@ -1163,7 +1170,7 @@ entryGetItem(RumState * rumstate, RumScanEntry entry, bool *nextEntryList, Snaps
 			RumScanItem *current_collected;
 
 			/* We are finished, but should return last result */
-			if (ItemPointerIsMax(&entry->collectRumItem.item.iptr))
+			if (RumItemPointerIsMax(&entry->collectRumItem.item.iptr))
 			{
 				entry->isFinished = true;
 				rum_tuplesort_end(entry->matchSortstate);
@@ -1172,12 +1179,12 @@ entryGetItem(RumState * rumstate, RumScanEntry entry, bool *nextEntryList, Snaps
 			}
 
 			/* collectRumItem could store the begining of current result */
-			if (!ItemPointerIsMin(&entry->collectRumItem.item.iptr))
+			if (!RumItemPointerIsMin(&entry->collectRumItem.item.iptr))
 				collected = entry->collectRumItem;
 			else
 				MemSet(&collected, 0, sizeof(collected));
 
-			ItemPointerSetMin(&entry->curItem.iptr);
+			RumItemPointerSetMin(&entry->curItem.iptr);
 
 			for(;;)
 			{
@@ -1199,14 +1206,14 @@ entryGetItem(RumState * rumstate, RumScanEntry entry, bool *nextEntryList, Snaps
 					break;
 				}
 
-				if (ItemPointerIsMin(&collected.item.iptr) ||
+				if (RumItemPointerIsMin(&collected.item.iptr) ||
 					rumCompareItemPointers(&collected.item.iptr,
 										   &current_collected->item.iptr) == 0)
 				{
 					Datum	joinedAddInfo = (Datum)0;
 					bool	joinedAddInfoIsNull;
 
-					if (ItemPointerIsMin(&collected.item.iptr))
+					if (RumItemPointerIsMin(&collected.item.iptr))
 					{
 						joinedAddInfoIsNull = true; /* will change later */
 						collected.item.addInfoIsNull = true;
@@ -1269,10 +1276,10 @@ entryGetItem(RumState * rumstate, RumScanEntry entry, bool *nextEntryList, Snaps
 			if (current_collected == NULL)
 			{
 				/* mark next call as last */
-				ItemPointerSetMax(&entry->collectRumItem.item.iptr);
+				RumItemPointerSetMax(&entry->collectRumItem.item.iptr);
 
 				/* even current call is last */
-				if (ItemPointerIsMin(&entry->curItem.iptr))
+				if (RumItemPointerIsMin(&entry->curItem.iptr))
 				{
 					entry->isFinished = true;
 					rum_tuplesort_end(entry->matchSortstate);
@@ -1609,7 +1616,7 @@ scanPage(RumState * rumstate, RumScanEntry entry, RumItem *item, bool equalOk)
 	int			cmp;
 	Page		page = BufferGetPage(entry->buffer);
 
-	ItemPointerSetMin(&iter_item.iptr);
+	RumItemPointerSetMin(&iter_item.iptr);
 
 	if (ScanDirectionIsForward(entry->scanDirection) && !RumPageRightMost(page))
 	{
@@ -1661,7 +1668,7 @@ scanPage(RumState * rumstate, RumScanEntry entry, RumItem *item, bool equalOk)
 	if (ScanDirectionIsBackward(entry->scanDirection) && first >= maxoff)
 	{
 		first = FirstOffsetNumber;
-		ItemPointerSetMin(&iter_item.iptr);
+		RumItemPointerSetMin(&iter_item.iptr);
 		ptr = RumDataPageGetData(page);
 	}
 
@@ -1741,7 +1748,11 @@ entryFindItem(RumState * rumstate, RumScanEntry entry, RumItem * item, Snapshot
 	{
 		if (compareRumItemScanDirection(rumstate, entry->attnumOrig,
 							entry->scanDirection,
-							&entry->curItem, item) >= 0)
+							&entry->curItem, item) >= 0 &&
+							entry->offset >= 0 &&
+							entry->offset < entry->nlist &&
+							rumCompareItemPointers(&entry->curItem.iptr,
+												   &entry->list[entry->offset].iptr) == 0)
 			return;
 		while (entry->offset >= 0 && entry->offset < entry->nlist)
 		{
